## $Id: utils.py 12615 2015-02-14 08:55:35Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper functions and utilities for the customer section.
"""

from copy import deepcopy
from waeup.ikoba.customers.utils import (
    CustomersUtils,
    STARTED, CREATED, REQUESTED, APPROVED,
    SUBMITTED, VERIFIED, REJECTED,
    EXPIRED, PROVISIONALLY)
from ikobacustom.pcn.interfaces import MessageFactory as _

class PCNCustomersUtils(CustomersUtils):
    """A collection of methods subject to customization.
    """

    #: A prefix used when generating new customer ids. Each customer id will
    #: start with this string. The default is 'K'.
    CUSTOMER_ID_PREFIX = u'K'

    DOCMANAGE_CUSTOMER_STATES = (REQUESTED, APPROVED, PROVISIONALLY)

    DOCMANAGE_DOCUMENT_STATES = (CREATED,)

    CONMANAGE_CUSTOMER_STATES = deepcopy(DOCMANAGE_CUSTOMER_STATES)

    CONMANAGE_CONTRACT_STATES = (CREATED,)

    DOCTYPES_DICT = {
        #'CustomerSampleDocument': _('Sample Document'),
        #'CustomerPDFDocument': _('PDF Document'),

        'PCNCustomerJPGDocument': _('JPG Document'),
        'PCNCustomerPDFDocument': _('PDF Document'),
        }

    CONTYPES_DICT = {
        #'SampleContract': _('Sample Contract'),

        'RONContract': _('Retention of Name on the Registrar'),
        'ROPContract': _('Registration of Premises'),
        'RPRContract': _('Registration in the Provisional Register'),
        'RPCContract': _('Registration as Pharmaceutical Chemist'),
        'IPPMVLContract': _(
            'Issuance of Patent and Proprietary Medicines Vendors License'),
        'RPPMVLContract': _(
            'Renewal of Patent and Proprietary Medicines Vendors License'),
        'APPITContract': _(
            'Accepting Pupil Pharmacist for Internship Training'),
        'RPTContract': _(
            'Registration as a Pharmacy Technician'),
        }




    SELECTABLE_DOCTYPES_DICT = deepcopy(DOCTYPES_DICT)

    SELECTABLE_CONTYPES_DICT = deepcopy(CONTYPES_DICT)

    EXPORTER_NAMES = (
        'customers',
        'pcncustomerjpgdocuments',
        'pcncustomerpdfdocuments',
        'roncontracts',
        'ropcontracts',
        'rprcontracts',
        'rpccontracts',
        'ippmvlcontracts',
        'rppmvlcontracts',
        'appitcontracts',
        'rptcontracts')
